@@ -132,7 +132,7 @@ def interceptor_error_log(trxid, e, fn, args, kwargs):
     
     p = logSinkPack.getLogSinkPack(
         t = DateUtil.now(),
-        category = "#UnhandledException",
+        category = "UnhandledException",
         tags = {'@txid': trxid},
         fields = fields,
         line=DateUtil.now(),
